Slicer package manager Python Client
====================================

Python client for managing Slicer application and extension packages
organized on a server with the corresponding Girder plugin installed.

The documentation is accessible at https://slicer-package-manager.readthedocs.io/en/latest/commands_shell.html#slicer-package-manager-client.

Installation
------------

Install with::

    $ pip install slicer-package-manager-client

or::

    $ git clone https://github.com/girder/slicer_package_manager.git
    $ cd slicer_package_manager/python_client
    $ pip install -e .

for development.

Resources
---------

To learn more about the Slicer package manager server and associated client, check out the following resources.

* https://slicer-package-manager.readthedocs.io/en/latest/commands_shell.html#slicer-package-manager-client
* https://slicer-package-manager.readthedocs.io

License
-------

This software is licensed under the terms of the `Apache Licence Version 2.0 <https://github.com/girder/slicer_package_manager/blob/main/LICENSE>`_.
